@@ -3,7 +3,7 @@
 int main(int argc, char **argv)
 {
 	if (start(argc, argv) != 0)
-		return (1);
+		return 1;
 
 	main_loop();
 
